"""Collection of 1D Elements
"""


from .Element1D import *
from .LinealElement import *
from .QuadraticElement import *
from .Element1D import *
from .LinearScheme import *
